@@ -1308,17 +1308,30 @@ c_complex mult(c_complex a,c_complex b){
   return c;
 }
 
-// transpose matrix in place
+// transpose matrix (in place for square matrices)
 void transpose(c_complex *x,int n,int m){
-  for (int i=1;i<n;++i){
-    for (int j=0;j<i;++j){
-      c_complex * a=x+i*m+j;
-      c_complex * b=x+j*m+i;
-      c_complex t=*a;
-      *a=*b;
-      *b=t;
+  if (n==m){
+    for (int i=1;i<n;++i){
+      for (int j=0;j<i;++j){
+	c_complex * a=x+i*m+j;
+	c_complex * b=x+j*m+i;
+	c_complex t=*a;
+	*a=*b;
+	*b=t;
+      }
+    }
+    return;
+  }
+  c_complex * tmp=(c_complex *) malloc(n*m*sizeof(c_complex));
+  if (!tmp)
+    return; // should error!
+  for (int i=0;i<n;++i){
+    for (int j=0;j<m;++j){
+      *(tmp+j*n+i)=*(x+i*m+j);
     }
   }
+  memcpy(x,tmp,n*m*sizeof(c_complex));
+  free(tmp);
 }
 
 
@@ -2031,11 +2044,13 @@ mp_obj_t turtle_ret(const char * val){
 
 static mp_obj_t turtle_forward(size_t n_args, const mp_obj_t *args) {
   turtle_freeze();
-  int i=10;
+  double i=10;
   if (n_args==1 && MP_OBJ_IS_SMALL_INT(args[0])) 
     i=MP_OBJ_SMALL_INT_VALUE(args[0]);
+  if (n_args==1 && mp_obj_is_float(args[0])) 
+    i=mp_obj_get_float(args[0]);
   char buf[256];
-  sprintf(buf,"avance(%i):;",i);
+  sprintf(buf,"avance(%.4g):;",i);
   const char * val=caseval(buf);
   return turtle_ret(val);
 }
@@ -2043,11 +2058,13 @@ MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(turtle_forward_obj, 0, 1, turtle_forward);
 
 static mp_obj_t turtle_backward(size_t n_args, const mp_obj_t *args) {
   turtle_freeze();
-  int i=10;
+  double i=10;
   if (n_args==1 && MP_OBJ_IS_SMALL_INT(args[0])) 
     i=MP_OBJ_SMALL_INT_VALUE(args[0]);
+  if (n_args==1 && mp_obj_is_float(args[0])) 
+    i=mp_obj_get_float(args[0]);
   char buf[256];
-  sprintf(buf,"recule(%i):;",i);
+  sprintf(buf,"recule(%.4g):;",i);
   const char * val=caseval(buf);
   return turtle_ret(val);
   return mp_obj_new_str(val,strlen(val));
@@ -2069,6 +2086,21 @@ static mp_obj_t turtle_left(size_t n_args, const mp_obj_t *args) {
 }
 MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(turtle_left_obj, 0, 1, turtle_left);
 
+static mp_obj_t turtle_pensize(size_t n_args, const mp_obj_t *args) {
+  turtle_freeze();
+  int i=1;
+  if (n_args==1 && MP_OBJ_IS_SMALL_INT(args[0])) 
+    i=MP_OBJ_SMALL_INT_VALUE(args[0]);
+  if (n_args==1 && mp_obj_is_float(args[0])) 
+    i=mp_obj_get_float(args[0]);
+  char buf[256];
+  sprintf(buf,"crayon -%i:;",i);
+  const char * val=caseval(buf);
+  return turtle_ret(val);
+  return mp_obj_new_str(val,strlen(val));
+}
+MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(turtle_pensize_obj, 0, 1, turtle_pensize);
+
 static mp_obj_t turtle_right(size_t n_args, const mp_obj_t *args) {
   turtle_freeze();
   int i=90;
@@ -2302,6 +2334,13 @@ static mp_obj_t turtle_write(size_t n_args, const mp_obj_t *args) {
 }
 MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(turtle_write_obj, 1, 1, turtle_write);
 
+static mp_obj_t turtle_colormode(size_t n_args, const mp_obj_t *args) {
+  if (n_args==0)
+    return mp_obj_new_int(255);    
+  return turtle_ret("");
+}
+MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(turtle_colormode_obj, 0, 1, turtle_colormode);
+
 static mp_obj_t turtle_pencolor(size_t n_args, const mp_obj_t *args) {
   turtle_freeze();
   int i=0;
@@ -2326,7 +2365,7 @@ static mp_obj_t turtle_pencolor(size_t n_args, const mp_obj_t *args) {
 	}
 	strcat(buf,"):;");
 #else
-	sprintf(buf,"crayon(%.3g,%.3g,%.3g):;",mp_obj_get_float(tab[0]),mp_obj_get_float(tab[1]),mp_obj_get_float(tab[2]));
+	sprintf(buf,"crayon(%.3f,%.3f,%.3f):;",mp_obj_get_float(tab[0]),mp_obj_get_float(tab[1]),mp_obj_get_float(tab[2]));
 #endif
       }
       if (n==3 &&  MP_OBJ_IS_SMALL_INT(tab[0]) && MP_OBJ_IS_SMALL_INT(tab[1]) && MP_OBJ_IS_SMALL_INT(tab[2])){
@@ -2334,6 +2373,9 @@ static mp_obj_t turtle_pencolor(size_t n_args, const mp_obj_t *args) {
       }
     }
   }
+  if (n_args==3 &&  MP_OBJ_IS_SMALL_INT(args[0]) && MP_OBJ_IS_SMALL_INT(args[1]) && MP_OBJ_IS_SMALL_INT(args[2])){
+    sprintf(buf,"crayon(%i,%i,%i):;",(int)MP_OBJ_SMALL_INT_VALUE(args[0]),(int)MP_OBJ_SMALL_INT_VALUE(args[1]),(int)MP_OBJ_SMALL_INT_VALUE(args[2]));
+  }
   if (n_args==3 && mp_obj_is_float(args[0]) && mp_obj_is_float(args[1]) && mp_obj_is_float(args[2]) ){
 #ifdef NUMWORKS
 	strcpy(buf,"crayon(");
@@ -2344,9 +2386,10 @@ static mp_obj_t turtle_pencolor(size_t n_args, const mp_obj_t *args) {
 	}
 	strcat(buf,"):;");
 #else
-    sprintf(buf,"crayon(%.3g,%.3g,%.3g):;",mp_obj_get_float(args[0]),mp_obj_get_float(args[1]),mp_obj_get_float(args[2]));
+    sprintf(buf,"crayon(%.3f,%.3f,%.3f):;",mp_obj_get_float(args[0]),mp_obj_get_float(args[1]),mp_obj_get_float(args[2]));
 #endif
   }
+  //printf(buf);
   const char * val=caseval(buf);
   return turtle_ret(val);
   return mp_obj_new_str(val,strlen(val));
@@ -2390,6 +2433,7 @@ static const mp_map_elem_t turtle_locals_dict_table[] = {
 	{ MP_ROM_QSTR(MP_QSTR_setx), (mp_obj_t) &turtle_setx_obj },
 	{ MP_ROM_QSTR(MP_QSTR_sety), (mp_obj_t) &turtle_sety_obj },
 	{ MP_ROM_QSTR(MP_QSTR_write), (mp_obj_t) &turtle_write_obj },
+	{ MP_ROM_QSTR(MP_QSTR_colormode), (mp_obj_t) &turtle_colormode_obj },
 	{ MP_ROM_QSTR(MP_QSTR_speed), (mp_obj_t) &turtle_speed_obj },
 	{ MP_ROM_QSTR(MP_QSTR_showturtle), (mp_obj_t) &turtle_showturtle_obj },
 	{ MP_ROM_QSTR(MP_QSTR_st), (mp_obj_t) &turtle_showturtle_obj },
@@ -2404,6 +2448,7 @@ static const mp_map_elem_t turtle_locals_dict_table[] = {
 	{ MP_ROM_QSTR(MP_QSTR_penup), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_pu), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_pencolor), (mp_obj_t) &turtle_pencolor_obj },
+	{ MP_ROM_QSTR(MP_QSTR_color), (mp_obj_t) &turtle_pencolor_obj },
 	{ MP_ROM_QSTR(MP_QSTR_avance), (mp_obj_t) &turtle_forward_obj },
 	{ MP_ROM_QSTR(MP_QSTR_av), (mp_obj_t) &turtle_forward_obj },
 	{ MP_ROM_QSTR(MP_QSTR_recule), (mp_obj_t) &turtle_backward_obj },
@@ -2425,12 +2470,12 @@ static const mp_map_elem_t turtle_locals_dict_table[] = {
 	{ MP_ROM_QSTR(MP_QSTR_cache_tortue), (mp_obj_t) &turtle_hideturtle_obj },
 	{ MP_ROM_QSTR(MP_QSTR_baisse_crayon), (mp_obj_t) &turtle_down_obj },
 	{ MP_ROM_QSTR(MP_QSTR_leve_crayon), (mp_obj_t) &turtle_up_obj },
+	{ MP_ROM_QSTR(MP_QSTR_pensize), (mp_obj_t) &turtle_pensize_obj },
 	/* { MP_ROM_QSTR(MP_QSTR_time), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_sleep), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_monotonic), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_time), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_sleep), (mp_obj_t) &turtle_up_obj },
-	{ MP_ROM_QSTR(MP_QSTR_pensize), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_width), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_isdown), (mp_obj_t) &turtle_up_obj },
 	{ MP_ROM_QSTR(MP_QSTR_isvisible), (mp_obj_t) &turtle_up_obj },
@@ -2473,6 +2518,7 @@ STATIC const mp_map_elem_t mp_module_turtle_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR_setx), (mp_obj_t) &turtle_setx_obj },
     { MP_ROM_QSTR(MP_QSTR_sety), (mp_obj_t) &turtle_sety_obj },
     { MP_ROM_QSTR(MP_QSTR_write), (mp_obj_t) &turtle_write_obj },
+    { MP_ROM_QSTR(MP_QSTR_colormode), (mp_obj_t) &turtle_colormode_obj },
     { MP_ROM_QSTR(MP_QSTR_speed), (mp_obj_t) &turtle_speed_obj },
     { MP_ROM_QSTR(MP_QSTR_showturtle), (mp_obj_t) &turtle_showturtle_obj },
     { MP_ROM_QSTR(MP_QSTR_st), (mp_obj_t) &turtle_showturtle_obj },
@@ -2487,6 +2533,7 @@ STATIC const mp_map_elem_t mp_module_turtle_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR_penup), (mp_obj_t) &turtle_up_obj },
     { MP_ROM_QSTR(MP_QSTR_pu), (mp_obj_t) &turtle_up_obj },
     { MP_ROM_QSTR(MP_QSTR_pencolor), (mp_obj_t) &turtle_pencolor_obj },
+    { MP_ROM_QSTR(MP_QSTR_color), (mp_obj_t) &turtle_pencolor_obj },
 	{ MP_ROM_QSTR(MP_QSTR_avance), (mp_obj_t) &turtle_forward_obj },
 	{ MP_ROM_QSTR(MP_QSTR_av), (mp_obj_t) &turtle_forward_obj },
 	{ MP_ROM_QSTR(MP_QSTR_recule), (mp_obj_t) &turtle_backward_obj },
@@ -2506,6 +2553,7 @@ STATIC const mp_map_elem_t mp_module_turtle_globals_table[] = {
 	{ MP_ROM_QSTR(MP_QSTR_cache_tortue), (mp_obj_t) &turtle_hideturtle_obj },
 	{ MP_ROM_QSTR(MP_QSTR_baisse_crayon), (mp_obj_t) &turtle_down_obj },
 	{ MP_ROM_QSTR(MP_QSTR_leve_crayon), (mp_obj_t) &turtle_up_obj },
+	{ MP_ROM_QSTR(MP_QSTR_pensize), (mp_obj_t) &turtle_pensize_obj },
 };
 
 STATIC const mp_obj_dict_t mp_module_turtle_globals = {
