@@ -4,11 +4,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-#ifndef IN_GIAC
-#include <giac/first.h>
-#else
 #include "first.h"
-#endif
 #ifdef HAVE_LIBFLTK
 #include <FL/Fl_Widget.H>
 #include <FL/Fl_Pack.H>
