@@ -113,7 +113,16 @@ namespace giac {
     }
     if (!assume_t_in_ab(t,plus_inf,plus_inf,true,true,contextptr))
       return gensizeerr(contextptr);
-    gen res=_integrate(gen(makevecteur(f*exp(-t*x,contextptr),x,0,plus_inf),_SEQ__VECT),contextptr);
+    int c=calc_mode(contextptr);
+    calc_mode(0,contextptr);
+    gen res=_integrate(makesequence(f*exp(-t*x,contextptr),x),contextptr);
+    calc_mode(c,contextptr);
+    if (lop(res,at_integrate).empty() && lop(res,at_piecewise).empty() && lop(res,at_sign).empty())
+      res=-_limit(makesequence(res,x,0,1),contextptr);
+    else
+      res=undef;
+    if (is_undef(res))
+      res=_integrate(makesequence(f*exp(-t*x,contextptr),x,0,plus_inf),contextptr);
     for (int i=1;i<=n;++i){
       if (is_undef(res))
 	return res;
@@ -205,7 +214,7 @@ namespace giac {
     return pf<gen>(p);
   }
 
-  static gen pf_ilaplace(const gen & e0,const gen & x, gen & remains,GIAC_CONTEXT){
+  static gen pf_ilaplace(const gen & e0,const gen & x, gen & remains,int,GIAC_CONTEXT){
     vecteur vexp;
     gen res;
     lin(e0,vexp,contextptr); // vexp = coeff, arg of exponential
@@ -344,7 +353,7 @@ namespace giac {
       return gensizeerr(contextptr);
     if (has_num_coeff(f))
       return ilaplace(exact(f,contextptr),x,s,contextptr);
-    gen remains,res=linear_apply(f,x,remains,contextptr,pf_ilaplace);
+    gen remains,res=linear_apply(f,x,remains,0,contextptr,pf_ilaplace);
     res=subst(res,laplace_var,s,false,contextptr);
     if (!is_zero(remains))
       res=res+symbolic(at_ilaplace,makevecteur(remains,x,s));
@@ -838,9 +847,9 @@ namespace giac {
 	      bool b=calc_mode(contextptr)==1;
 	      if (b)
 		calc_mode(0,contextptr);
-	      gen tmp=_lin(c[i]*exp(-rac[i]*x,contextptr),contextptr);
+	      gen tmp=_lin(makesequence(c[i]*exp(-rac[i]*x,contextptr),at_sqrt),contextptr);
 	      tmp = _integrate(makesequence(tmp,x),contextptr);
-	      part += _lin(tmp*exp(rac[i]*x,contextptr),contextptr);
+	      part += _lin(makesequence(tmp*exp(rac[i]*x,contextptr),at_sqrt),contextptr);
 	      if (b)
 		calc_mode(1,contextptr);
 	    }
@@ -879,6 +888,15 @@ namespace giac {
       gen & b=v[1];
       gen & c=v[2];
       gen & d=cst;
+#if 0
+      if (is_exactly_zero(c)){
+	vecteur v1(makevecteur(a,b,d));
+	if (desolve_linn(x,y,t,1,v1,parameters,result,step_info,contextptr)){
+	  result=_integrate(makesequence(result,x),contextptr);
+	  return true;
+	}
+      }
+#endif
       gen u=-b/a,V=-c/a,w=-d/a,
 	k=simplify(u*u/4-derive(u,x,contextptr)/2+V,contextptr);
       // y''=u*y'+V*y+w  (with u,V,w functions of x)
@@ -1062,9 +1080,9 @@ namespace giac {
     num=false;
     // if x_orig.type==_VECT || y_orig.type==_VECT, they should be evaled
     if (x_orig.type!=_VECT && eval(x_orig,1,contextptr)!=x_orig)
-      return gensizeerr("Independant variable assigned. Run purge("+x_orig.print(contextptr)+")\n");
+      return gensizeerr("Independent variable assigned. Run purge("+x_orig.print(contextptr)+")\n");
     if (y_orig.type!=_VECT && eval(y_orig,1,contextptr)!=y_orig)
-      return gensizeerr("Dependant variable assigned. Run purge("+y_orig.print(contextptr)+")\n");
+      return gensizeerr("Dependent variable assigned. Run purge("+y_orig.print(contextptr)+")\n");
     gen x(x_orig);
     if ( (x_orig.type==_VECT) && (x_orig._VECTptr->size()==1) )
       x=x_orig._VECTptr->front();
@@ -1592,7 +1610,7 @@ namespace giac {
     return ggbputinlist(desolve( v[0],v[1],v[2],ordre,parameters,contextptr),contextptr);    
   }
   static const char _desolve_s []="desolve";
-  static define_unary_function_eval (__desolve,&_desolve,_desolve_s);
+  static define_unary_function_eval_quoted (__desolve,&_desolve,_desolve_s);
   define_unary_function_ptr5( at_desolve ,alias_at_desolve,&__desolve,1,true);
 
   static const char _dsolve_s []="dsolve";
@@ -2086,7 +2104,7 @@ namespace giac {
     gen laur=_series(makesequence(r,x,inf,1,_POLY1__VECT),contextptr);
     bool success=false;
     if (kovacic_iscase1(poles,dinf)) {
-      cerr << "Case 1 of Kovacic algorithm" << '\n';
+      //cerr << "Case 1 of Kovacic algorithm" << '\n';
       /* step 1 */
       gen_map alpha_plus,alpha_minus,sqrt_r;
       gen alpha_inf_plus,alpha_inf_minus;
@@ -2187,7 +2205,7 @@ namespace giac {
       }
     }
     if (!success && kovacic_iscase2(poles)) {
-      cerr << "Case 2 of Kovacic algorithm" << '\n';
+      //cerr << "Case 2 of Kovacic algorithm" << '\n';
       /* step 1 */
       gen_map E;
       for (const_iterateur it=poles.begin();it!=poles.end();++it) {
@@ -2280,7 +2298,7 @@ namespace giac {
       }
     }
     if (!success && kovacic_iscase3(cpfr,x,poles,dinf,contextptr)) {
-      cerr << "Case 3 of Kovacic algorithm" << '\n';
+      //cerr << "Case 3 of Kovacic algorithm" << '\n';
       vector<int> nv=vecteur_2_vector_int(makevecteur(4,6,12));
       for (vector<int>::const_iterator nt=nv.begin();nt!=nv.end();++nt) {
 	int n=*nt;
@@ -2349,7 +2367,7 @@ namespace giac {
 	  v=vecteur(vars.begin(),vars.begin()+deg);
 	  for (int i=0;i<deg;++i) P[n+1]-=v[i]*pow(x,i);
 	  P[n+1]-=pow(x,deg);
-	  P[n]=-S*(_derive(makesequence(P[n+1],x),contextptr)+th*P[n+1]),contextptr;
+	  P[n]=-S*(_derive(makesequence(P[n+1],x),contextptr)+th*P[n+1]);
 	  if (P[n].type==_SYMB) P[n]=_collect(P[n],contextptr);
 	  for (int i=n;i-->0;) {
 	    P[i]=-S*_derive(makesequence(P[i+1],x),contextptr)+((n-i)*dS-S*th)*P[i+1]-(n-i)*(i+1)*sq(S)*r*P[i+2];
@@ -2367,7 +2385,7 @@ namespace giac {
 	    for (int i=0;i<=n;++i) {
 	      ac[i]=_collect(pow(S,i)*P[i+1]/_factorial(n-i,contextptr),contextptr);
 	    }
-	    *logptr(contextptr) << "Warning: outputting the algebraic expression for ω" << '\n';
+        //*logptr(contextptr) << "Warning: outputting the algebraic expression for ω" << '\n';
 	    ac=strip_gcd(ac,contextptr);
 	    gen omg=pow(w,4)*ac[4]+pow(w,3)*ac[3]+pow(w,2)*ac[2]+w*ac[1]+ac[0];
 	    if (!is_zero(dy_coeff)) {
@@ -2460,7 +2478,7 @@ namespace giac {
     return kovacicsols(r,x,p,contextptr);
   }
   static const char _kovacicsols_s []="kovacicsols";
-  static define_unary_function_eval (__kovacicsols,&_kovacicsols,_kovacicsols_s);
+  static define_unary_function_eval_quoted (__kovacicsols,&_kovacicsols,_kovacicsols_s);
   define_unary_function_ptr5(at_kovacicsols,alias_at_kovacicsols,&__kovacicsols,_QUOTE_ARGUMENTS,true)
 
   /*
