@@ -73,6 +73,8 @@ namespace giac {
     _INT___VECT = _INT_*_DISPATCHBASE+_VECT,
     _INT___MAP = _INT_*_DISPATCHBASE+_MAP,
     _INT___REAL = _INT_*_DISPATCHBASE+_REAL,
+    _INT___FRAC = _INT_*_DISPATCHBASE+_FRAC,
+    _INT___STRNG = _INT_*_DISPATCHBASE+_STRNG,
     _ZINT__INT_ = _ZINT*_DISPATCHBASE+_INT_,
     _ZINT__ZINT =_ZINT*_DISPATCHBASE+_ZINT,
     _ZINT__CPLX = _ZINT*_DISPATCHBASE+_CPLX,
@@ -84,6 +86,7 @@ namespace giac {
     _ZINT__VECT = _ZINT*_DISPATCHBASE+_VECT,
     _ZINT__MAP = _ZINT*_DISPATCHBASE+_MAP,
     _ZINT__REAL = _ZINT*_DISPATCHBASE+_REAL,
+    _ZINT__FRAC = _ZINT*_DISPATCHBASE+_FRAC,
     _CPLX__INT_ = _CPLX*_DISPATCHBASE+_INT_,
     _CPLX__ZINT = _CPLX*_DISPATCHBASE+_ZINT,
     _CPLX__CPLX = _CPLX*_DISPATCHBASE+_CPLX,
@@ -140,6 +143,7 @@ namespace giac {
     _DOUBLE___MAP = _DOUBLE_*_DISPATCHBASE+_MAP,
     _DOUBLE___REAL = _DOUBLE_*_DISPATCHBASE+_REAL,
     _DOUBLE___FRAC = _DOUBLE_*_DISPATCHBASE+_FRAC,
+    _DOUBLE___STRNG = _DOUBLE_*_DISPATCHBASE+_STRNG,
     _FLOAT___INT_=  _FLOAT_*_DISPATCHBASE+_INT_,
     _FLOAT___ZINT = _FLOAT_*_DISPATCHBASE+_ZINT,
     _FLOAT___CPLX = _FLOAT_*_DISPATCHBASE+_CPLX,
@@ -184,14 +188,18 @@ namespace giac {
     _FRAC__FLOAT_ = _FRAC*_DISPATCHBASE+_FLOAT_,
     _FRAC__DOUBLE_ = _FRAC*_DISPATCHBASE+_DOUBLE_,
     _FRAC__INT_=  _FRAC*_DISPATCHBASE+_INT_,
+    _FRAC_ZINT=  _FRAC*_DISPATCHBASE+_ZINT,
     _FRAC__REAL=  _FRAC*_DISPATCHBASE+_REAL,
     _SPOL1__SPOL1 = _SPOL1*_DISPATCHBASE+_SPOL1,
     _EXT__EXT = _EXT*_DISPATCHBASE+_EXT,
     _EXT__VECT = _EXT*_DISPATCHBASE+_VECT,
     _EXT__MAP = _EXT*_DISPATCHBASE+_MAP,
     _EXT__INT_=  _EXT*_DISPATCHBASE+_INT_,
+    _EXT__ZINT =  _EXT*_DISPATCHBASE+_ZINT,
     _EXT__POLY=  _EXT*_DISPATCHBASE+_POLY,
     _STRNG__STRNG = _STRNG*_DISPATCHBASE+_STRNG,
+    _STRNG__INT_=  _STRNG*_DISPATCHBASE+_INT_,
+    _STRNG__DOUBLE_=  _STRNG*_DISPATCHBASE+_DOUBLE_,
     _FUNC__FUNC = _FUNC*_DISPATCHBASE+_FUNC,
     _MOD__MOD = _MOD*_DISPATCHBASE+_MOD,
     _ZINT__MOD = _ZINT*_DISPATCHBASE+_MOD,
@@ -251,11 +259,15 @@ namespace giac {
     _GGBVECT=27,
     _PRINT__VECT=28,
     _TUPLE__VECT=29,
+    _TABLE__VECT=30,
+    _GRAPH__VECT =31,
+    _PRG__VECT=32,
   } ;
 
   enum symb_subtypes {
     _GLOBAL__EVAL =-1,
-    _SPREAD__SYMB =123 // do not use this value elsewhere
+    _SPREAD__SYMB =123, // do not use this value elsewhere
+    _FORCHK__SYMB=124, // cached subtype value for for inside a for loop
   } ;
 
   enum map_subtypes {
@@ -459,10 +471,21 @@ namespace giac {
     _CONTEXT_POINTER=3,
     _THREAD_POINTER=4,
     _VARFUNCDEF_POINTER=5,
-    _APPLET_POINTER=6
+    _APPLET_POINTER=6,
+    _BUFFER_POINTER=7,
   };
 
   enum color_values {
+#ifdef KHICAS
+    _BLACK=0,
+    _RED=0xf800,
+    _GREEN=0x0400,
+    _YELLOW=0xffe0,
+    _BLUE=0x001f,
+    _MAGENTA=0xf81f,
+    _CYAN=0x07ff,
+    _WHITE=0xffff,
+#else // KHICAS
 #ifdef GIAC_HAS_STO_38
     _WHITE=0,
 #else
@@ -479,6 +502,7 @@ namespace giac {
 #else
     _WHITE=7,
 #endif
+#endif // KHICAS
     _POINT_LOSANGE= 1 << 25,
     _POINT_PLUS = 1 << 26,
     _POINT_INVISIBLE = 1 << 27,
@@ -538,6 +562,62 @@ namespace giac {
     _NEGINT=2*256+2,
     _NONPOSINT=3*256+2,
     _NONNEGINT=4*256+2,
+    _LP_BINARY=106,                // lp_binary
+    _LP_BINARYVARIABLES=107,       // lp_binaryvariables
+    _LP_DEPTHLIMIT=108,            // lp_depthlimit
+    _LP_INTEGER=109,               // lp_integer
+    _LP_INTEGERVARIABLES=110,      // lp_integervariables
+    _LP_MAXIMIZE=111,              // lp_maximize
+    _LP_NONNEGATIVE=112,           // lp_nonnegative
+    _LP_NONNEGINT=113,             // lp_nonnegint
+    _LP_ASSUME=114,                // lp_assume
+    _LP_NODE_LIMIT = 115,          // lp_nodelimit
+    _LP_METHOD = 116,              // lp_method
+    _LP_SIMPLEX = 117,             // lp_simplex
+    _LP_INTERIOR_POINT = 118,      // lp_interiorpoint
+    _LP_MAX_CUTS = 119,            // lp_maxcuts
+    _LP_GAP_TOLERANCE = 120,       // lp_gaptolerance
+    _LP_NODESELECT = 121,          // lp_nodeselect
+    _LP_VARSELECT = 122,           // lp_varselect
+    _LP_FIRSTFRACTIONAL = 123,     // lp_firstfractional
+    _LP_LASTFRACTIONAL = 124,      // lp_lastfractional
+    _LP_MOSTFRACTIONAL = 125,      // lp_mostfractional
+    _LP_PSEUDOCOST = 126,          // lp_pseudocost
+    _LP_DEPTHFIRST = 127,          // lp_depthfirst
+    _LP_BREADTHFIRST = 128,        // lp_breadthfirst
+    _LP_BEST_LOCAL_BOUND = 129,    // lp_bestlocalbound
+    _LP_BEST_PROJECTION = 130,     // lp_bestprojection
+    _LP_HYBRID = 131,              // lp_hybrid
+    _LP_ITERATION_LIMIT = 132,     // lp_iterationlimit
+    _LP_TIME_LIMIT = 133,          // lp_timelimit
+    _LP_VERBOSE = 134,             // lp_verbose
+    _LP_PRESOLVE = 135,            // lp_presolve
+    _LP_HEURISTIC = 136,           // lp_heuristic
+    _NLP_INITIALPOINT = 137,       // nlp_initialpoint
+    _NLP_ITERATIONLIMIT = 138,     // nlp_iterationlimit
+    _NLP_NONNEGATIVE = 139,        // nlp_nonnegative
+    _NLP_PRECISION = 140,          // nlp_precision
+    _NLP_MAXIMIZE = 141,           // nlp_maximize
+    _NLP_PRESOLVE = 142,           // nlp_presolve
+    _NLP_SAMPLES = 143,            // nlp_samples
+    _NLP_INTEGER = 144,            // nlp_integer
+    _NLP_INTEGERVARIABLES = 145,   // nlp_integervariables
+    _NLP_BINARY = 146,             // nlp_binary
+    _NLP_BINARYVARIABLES = 147,    // nlp_binaryvariables
+    _NLP_NONNEGINT = 148,          // nlp_nonnegint
+    _NLP_FEAS_TOL = 149,           // nlp_feasibilitytolerance
+    _NLP_INT_TOL = 150,            // nlp_integertolerance
+    _GT_CONNECTED = 151,           // connected
+    _GT_SPRING = 152,              // spring
+    _GT_TREE = 153,                // tree
+    _GT_PLANAR = 154,              // planar
+    _GT_DIRECTED = 155,            // directed
+    _GT_WEIGHTED = 156,            // weighted
+    _GT_WEIGHTS = 157,             // weights
+    _GT_BIPARTITE = 158,           // bipartite
+    _GT_ACYCLIC = 159,             // acyclic
+    _KDE_BANDWIDTH = 160,          // bandwidth
+    _KDE_BINS = 161,               // bins
   };
 
   enum mupad_operator {
@@ -591,6 +671,8 @@ namespace giac {
     step_derive_header=34,
   };
 
+
+
 #ifndef NO_NAMESPACE_GIAC
 } // namespace giac
 #endif // ndef NO_NAMESPACE_GIAC
