@@ -666,7 +666,8 @@ namespace giac {
 #if defined POCKETCAS
 	  param_curves.push_back(makevecteur(tmp,t,-10,10,0.1,q,ratparam));
 #else
-	  param_curves.push_back(makevecteur(tmp,t,-3.14,3.14,0.0314,q,ratparam));
+	  double tt=lop(tmp,at_cosh).empty()?3.14:2.8;
+	  param_curves.push_back(makevecteur(tmp,t,-tt,tt,tt/100,q,ratparam));
 #endif
 	  if (noratparam){
 	    if (numeric){
@@ -680,7 +681,7 @@ namespace giac {
 #if defined POCKETCAS
 	    param_curves.push_back(makevecteur(tmp,t,-10,10,0.1,q,ratparam));
 #else
-	    param_curves.push_back(makevecteur(tmp,t,-3,3,0.1,q,ratparam));
+	    param_curves.push_back(makevecteur(tmp,t,-tt,tt,tt/100,q,ratparam));
 #endif
 	  }
 	}
@@ -781,8 +782,10 @@ namespace giac {
       if (!is_zero(s2)){
 	if (!is_zero(s3)){
 	  gen tmp=normal(-c1/s1*u-c2/s2*v-c3/s3*w,contextptr);
-	  if (tmp.type!=_VECT || tmp._VECTptr->size()!=3)
+	  if (tmp.type!=_VECT)
 	    return false;
+	  while (tmp._VECTptr->size()<3)
+	    tmp._VECTptr->insert(tmp._VECTptr->begin(),0);
 	  centre=*tmp._VECTptr;
 	  d=normal(subst(q,vxyz,centre,false,contextptr),contextptr);
 	  equation_reduite=s1*pow(x,2)+s2*pow(y,2)+s3*pow(z,2)+d;
