@@ -10,7 +10,7 @@ int main(){
 }
 #else
 /*
- *  Copyright (C) 2000,2014 B. Parisse, Institut Fourier, 38402 St Martin d'Heres
+ *  Copyright (C) 2000,2020 B. Parisse, Institut Fourier, 38402 St Martin d'Heres
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -76,6 +76,10 @@ using namespace std;
 #include <signal.h>
 #endif
 #include "Python.h"
+#include "qjsgiac.h"
+#ifdef __MINGW_H
+#include <direct.h>
+#endif
 
 // using namespace giac;
 #ifdef HAVE_LIBREADLINE
@@ -193,13 +197,20 @@ void format_plugin () {
   cout << TEXMACS_DATA_END;
 }
 
-void flush_stdout(){
+void flush_stdout(int slp = 0){
 #ifdef NSPIRE_NEWLIB
   giac::usleep(2000);
 #else
   usleep(2000);
 #endif
   fflush (stdout);
+  if (slp>0) {
+#ifdef NSPIRE_NEWLIB
+    giac::usleep(slp*1000);
+#else
+    usleep(slp*1000);
+#endif
+  }
 }
 
 void flush_stderr(){
@@ -220,44 +231,73 @@ void texmacs_next_input () {
   flush_stdout();
 }
 
-#define TEXMACS_IMAGE_SCALE 57.0 // percent
-#define TEXMACS_IMAGE_PADDING_ABOVE 1.75 // ex
-#define TEXMACS_IMAGE_PADDING_BELOW 1.75 // ex
-
-void ifstream_output(istream & tmpif){
-  flush_stdout();
-  putchar(TEXMACS_DATA_BEGIN);
-#if 0 // changes by L. Marohnić
-  printf("scheme:(padded-centered \"%gex\" \"%gex\" (document (image (tuple (raw-data \"",
-         TEXMACS_IMAGE_PADDING_ABOVE,TEXMACS_IMAGE_PADDING_BELOW);
-  char c;
-  for (int j=1;!tmpif.eof();++j){
-    tmpif.get(c);
-    putchar(c);
-  }
-  printf("\") \"eps\") \"%g%%\" \"\" \"\" \"\")))",TEXMACS_IMAGE_SCALE);
+bool texmacs_graph_lr_margins(const string &fname,int &val,bool init=true,int width=0) {
+  char buffer[1024];
+  int left,w;
+#ifdef __MINGW_H
+  string devnull=" 2>nul";
 #else
-  printf("ps:");
-  char c;
-  for (int j=1;!tmpif.eof();++j){
-    tmpif.get(c);
-    putchar(c);
-    if (!(j%1024))
-      flush_stdout();
-  }
-  putchar('\n');
+  string devnull=" 2>/dev/null";
 #endif
-  putchar(TEXMACS_DATA_END);
-  flush_stdout();
+  FILE *pipe=popen(((init?"pdfcrop --verbose ":"pdfinfo ")+fname+devnull).c_str(),"r");
+  if (!pipe) return false;
+  try {
+    int i=-1,j;
+    while(fgets(buffer,sizeof(buffer),pipe)!=NULL) {
+      string line(buffer);
+      if (init) {
+        if (line.substr(2,12)=="BoundingBox:") {
+          line=line.substr(15);
+          i=line.find_first_of(' ');
+          left=atoi(line.substr(0,i).c_str());
+          j=line.find_first_of(' ',i+1)+1;
+          i=line.find_last_of(' ');
+          w=atoi(line.substr(j,i-j).c_str());
+          break;
+        }
+      } else {
+        if (line.substr(0,10)=="Page size:") {
+          for (i=10;line[i]==' ';++i);
+          for (j=i;line[j]!=' ';++j);
+          val=atoi(line.substr(i,j-i).c_str())-width;
+          break;
+        }
+      }
+    }
+    if (i<0)
+      return false;
+  } catch (...) {
+    pclose(pipe);
+    return false;
+  }
+  pclose(pipe);
+  if (init) {
+    int right;
+    if (!texmacs_graph_lr_margins(fname,right,false,w))
+      return false;
+    val=(left+right)/2;
+  }
+  return true;
 }
 
-
+bool system_status_ok(int status) {
+  return status!=-1
+#ifndef __MINGW_H
+		&& WEXITSTATUS(status)==0
+#endif
+    ;
+}
 
 void texmacs_graph_output(const giac::gen & g,giac::gen & gg,std::string & figfilename,int file_type,const giac::context * contextptr){
 #if 1 // changes by L. Marohnić
   char buf[L_tmpnam];
   bool has_temp_file=(tmpnam(buf)!=NULL);
-  string tmpname(has_temp_file?buf:"casgraph"),ext=".eps",extc="-cleaned.eps";
+  string tmpname(has_temp_file?buf:"casgraph");
+#ifdef _WIN32
+  string tmpdir=getenv("TEMP")?getenv("TEMP"):"c:\\Users\\Public";
+  tmpname=tmpdir+"\\"+tmpname;
+#endif
+  string ext=".eps",extc=".pdf";
   if (!xcas::fltk_view(g,gg,tmpname+ext,figfilename,file_type,contextptr)){
     putchar(TEXMACS_DATA_BEGIN);
     printf("verbatim:Plot cancelled or unable to plot\n");
@@ -279,23 +319,67 @@ void texmacs_graph_output(const giac::gen & g,giac::gen & gg,std::string & figfi
     flush_stdout();
   }
   else {
-    bool cleaned=false;
+    bool cleaned=false,cropped=false,no_pdfcrop=true;
+#ifdef HAVE_SYSTEM
     if (system(NULL)) {
-      int status;
-      status=system(("eps2eps "+tmpname+ext+" "+tmpname+extc).c_str());
-      if (status!=-1 && WEXITSTATUS(status)==0)
-        cleaned=true;
+#ifdef __MINGW_H
+      no_pdfcrop=system("where pdfcrop >nul") || system("where pdfinfo >nul");
+#else
+      no_pdfcrop=system("which pdfcrop >/dev/null 2>&1") || system("which pdfinfo >/dev/null 2>&1");
+#endif
+      stringstream ss;
+      int lr,status;
+#ifdef __MINGW_H
+      cleaned=system_status_ok(system(("eps2eps "+tmpname+ext+" "+tmpname+"-cleaned"+ext).c_str())) &&
+              system_status_ok(system(("ps2pdf -dEPSCrop "+tmpname+"-cleaned"+ext+" "+tmpname+extc).c_str()));
+#else
+      status=system(("eps2eps "+tmpname+ext+" - | ps2pdf -dEPSCrop - "+tmpname+extc).c_str());
+      cleaned=system_status_ok(status);
+#endif
+      if (cleaned && !no_pdfcrop) {
+        if (!texmacs_graph_lr_margins(tmpname+extc,lr))
+          no_pdfcrop=true;
+        else ss << lr << " 0 " << lr << " 0";
+      }
+      string mrg=ss.str();
+      if (cleaned && !no_pdfcrop) {
+#ifdef __MINGW_H
+        string devnull=" >nul";
+#else
+        string devnull=" >/dev/null 2>&1";
+#endif
+        status=system(("pdfcrop --margins '"+mrg+"' "+tmpname+extc+" "+tmpname+"-cropped"+extc+devnull).c_str());
+        cropped=system_status_ok(status);
+      }
     }
-    ifstream tmpif((tmpname+(cleaned?extc:ext)).c_str());
-    ifstream_output(tmpif); // send PS to TeXmacs
-    // remove temporary files:
+#endif
+    usleep(10000);
+    putchar(TEXMACS_DATA_BEGIN);
+    printf("scheme:(htab \"\")");
+    putchar(TEXMACS_DATA_END);
+    putchar(TEXMACS_DATA_BEGIN);
+    printf("file:%s", (tmpname+(cropped?"-cropped":"")+(cleaned?extc:ext)).c_str());
+    putchar(TEXMACS_DATA_END);
+    putchar(TEXMACS_DATA_BEGIN);
+    printf("scheme:(htab \"\")");
+    putchar(TEXMACS_DATA_END);
+    flush_stdout(200);
+    // remove temporary files
     bool remove_fail=false;
     if (remove((tmpname+ext).c_str())!=0)
       remove_fail=true;
     if (cleaned) {
+#ifdef __MINGW_H
+      if (remove((tmpname+"-cleaned"+ext).c_str())!=0)
+        remove_fail=true;
+#endif
       if (remove((tmpname+extc).c_str())!=0)
         remove_fail=true;
     }
+    if (cropped) {
+      if (remove((tmpname+"-cropped"+extc).c_str())!=0)
+        remove_fail=true;
+    }
     if (remove_fail)
       cerr << "Warning: failed to remove temporary file(s)\n";
   }
@@ -363,7 +447,7 @@ void texmacs_output(const giac::gen & g,giac::gen & gg,bool reading_file,int no,
   if (gg.type==giac::_STRNG)
     printf("verbatim:%s\n",gg._STRNGptr->c_str());
   else 
-    printf("scheme:(document (math (with \"math-display\" \"true\" %s)))",giac::gen2scm(gg,giac::context0).c_str());
+    printf("scheme:(document (equation* (math %s)))",giac::gen2scm(gg,giac::context0).c_str());
 #else
   if (reading_file){
     putchar(TEXMACS_DATA_BEGIN);
@@ -1039,7 +1123,22 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 }
 #endif
 
-int micropy_evaled(string & s,const giac::context * contextptr){
+int micropyjs_evaled(string & s,const giac::context * contextptr){
+#ifdef QUICKJS
+  if (python_compat(contextptr) <0){
+    if (s.size() && s[0]=='@')
+      s=s.substr(1,s.size()-1);
+    else
+      s="\"use math\";"+s;
+    char * js=js_ck_eval(s.c_str(),&global_js_context);
+    if (js){
+      printf("%s\n",js);
+      free(js);
+    }
+    else printf("%s\n","QuickJS error");
+    return 1;
+  }
+#endif
 #ifdef HAVE_LIBMICROPYTHON
   if (python_compat(contextptr) & 4){
     const char * ptr=s.c_str();
@@ -1050,10 +1149,10 @@ int micropy_evaled(string & s,const giac::context * contextptr){
     bool turt=strcmp(ptr,".")==0;
     if (!gr && !pix && !turt){
       giac::python_contextptr=contextptr;
-      python_console="";
+      python_console()="";
       int i=micropy_ck_eval(s.c_str());
-      cout << python_console ;
-      return true;
+      cout << python_console() ;
+      return 1;
     }
     giac::context * cascontextptr=(giac::context *)giac::caseval("caseval contextptr");
     if (gr){
@@ -1069,11 +1168,13 @@ int micropy_evaled(string & s,const giac::context * contextptr){
     }
   }
 #endif
-  return false;
+  return 0;
 }
 
 int main(int ARGC, char *ARGV[]){    
+#ifdef HAVE_LIBFLTK
   giac::__get_key.op=&xcas::Xcas_fltk_getKey;
+#endif
   //giac::step_infolevel=1;
   cerr << "// Maximum number of parallel threads " << giac::threads << '\n';
   giac::context giac_context;
@@ -1143,7 +1244,7 @@ int main(int ARGC, char *ARGV[]){
   }
 #endif
   if (ARGC==2 && (string(ARGV[1])=="-v" || string(ARGV[1])=="--version" ) ){
-    cout << "// (c) 2001, 2018 B. Parisse & others" << '\n';
+    cout << "// (c) 2001, 2021 B. Parisse & others" << '\n';
     cout << GIAC_VERSION << '\n';
 #ifndef GNUWINCE
     return 0;
@@ -1152,9 +1253,9 @@ int main(int ARGC, char *ARGV[]){
   //signal(SIGUSR1,data_signal_handler);
   //signal(SIGUSR2,plot_signal_handler);
   giac::child_id=1;
-  bool intexmacs=((ARGC>=2) && std::string(ARGV[1])=="--texmacs");
   bool inemacs=((ARGC>=2) && std::string(ARGV[1])=="--emacs");
   bool insage=((ARGC>=2) && std::string(ARGV[1])=="--sage");
+  bool intexmacs=((ARGC>=2) && std::string(ARGV[1])=="--texmacs");
   if (inemacs){
     putchar(EMACS_DATA_BEGIN);
     putchar(EMACS_ERROR);
@@ -1267,7 +1368,7 @@ int main(int ARGC, char *ARGV[]){
       if (getenv("XCAS_HELP"))
 	giac::readhelp((*giac::vector_aide_ptr()),getenv("XCAS_HELP"),helpitems,true);
       else
-	giac::readhelp((*giac::vector_aide_ptr()),(giac::giac_aide_dir()+"aide_cas").c_str(),helpitems,true);
+	giac::readhelp((*giac::vector_aide_ptr()),(giac::giac_aide_dir()+"aide_cas").c_str(),helpitems,false);
     }
 #ifdef STATIC_BUILTIN_LEXER_FUNCTIONS
   }
@@ -1297,7 +1398,7 @@ int main(int ARGC, char *ARGV[]){
     printf("Giac CAS for mupacs, released under the GPL license 3.0\n");
     printf("See http://www.gnu.org for license details\n");
     printf("May contain BSD licensed software parts (lapack, atlas, tinymt)\n");
-    printf("| (c) 2006, 2018 B. Parisse & al (giac), F.Maltey & al (mupacs) |\n");
+    printf("| (c) 2006, 2021 B. Parisse & al (giac), F.Maltey & al (mupacs) |\n");
     putchar(EMACS_DATA_END);
     bool prompt=true;
     for (int k=0;;++k) {
@@ -1479,19 +1580,24 @@ int main(int ARGC, char *ARGV[]){
   if ( intexmacs){
     giac::html_help_init(ARGV[0],false);
     giac::enable_texmacs_compatible_latex_export(true);
-    int out_handle;
 #ifdef WITH_GNUPLOT
+    int out_handle;
     giac::run_gnuplot(out_handle);
 #endif
     putchar(TEXMACS_DATA_BEGIN);
-    // printf("verbatim:");
-    // format_plugin();
-    printf("latex:");
+    printf("verbatim:");
     format_plugin();
-    printf("{\\centering\\begin{tabular}{|c|}\\hline Giac CAS for TeXmacs, released under the GPL license (3.0)\\\\See \\url{http://www.gnu.org} for license details\\\\May contain BSD licensed software parts (lapack, atlas, tinymt)\\\\\\copyright\\ 2003--2019 B. Parisse \\& al (giac), J. van der Hoeven (TeXmacs)\\\\\\hline\\end{tabular}\\par}");
-    putchar(TEXMACS_DATA_END);
     putchar(TEXMACS_DATA_BEGIN);
-    printf("verbatim:\n\n");
+    printf("scheme:(hrule)");
+    putchar(TEXMACS_DATA_END);
+    printf("\nGiac %s for TeXmacs, released under the GPL license (3.0)\n",PACKAGE_VERSION);
+    printf("See www.gnu.org for license details\n");
+    printf("May contain BSD licensed software parts (lapack, atlas, tinymt)\n");
+    printf("© 2003–2021 B. Parisse & al (giac), J. van der Hoeven (TeXmacs), L. Marohnić (interface)\n");
+    putchar(TEXMACS_DATA_BEGIN);
+    printf("scheme:(hrule)");
+    putchar(TEXMACS_DATA_END);
+    printf("\n");
     switch (giac::xcas_mode(contextptr)){
     case 0:
       printf("Xcas (C-like) syntax mode\n");
@@ -1509,8 +1615,15 @@ int main(int ARGC, char *ARGV[]){
     printf("Type tabulation key to complete a partial command\n");
     putchar(TEXMACS_DATA_END);
     texmacs_next_input();
+#ifdef __MINGW_H
+    char buf[4096];
+#endif
     while (1) {      
       string buffer;
+#ifdef __MINGW_H
+      cin.getline(buf,4096,'\n');
+      buffer=string(buf);
+#else
       char car;//,nxt;
       for (;;){
 	int i=getchar();
@@ -1519,13 +1632,13 @@ int main(int ARGC, char *ARGV[]){
 	  break;
 	car=i;
 	if (car=='\n'){
-#if !defined VISUALC && !defined __MINGW_H
+#if !defined VISUALC
 	  giac::set_nonblock_flag(STDIN_FILENO,1); // set non blocking mode on stdin
 #endif
 	  usleep(5000);
 	  // ssize_t s=read(STDIN_FILENO,&nxt,1);
 	  i=getchar();
-#if !defined VISUALC && !defined __MINGW_H
+#if !defined VISUALC
 	  giac::set_nonblock_flag(STDIN_FILENO,0); // set blocking mode on stdin
 #endif
 	  // cerr << "read "  << s << '\n';
@@ -1538,6 +1651,7 @@ int main(int ARGC, char *ARGV[]){
 	else
 	  buffer +=car;
       }
+#endif
       // end read buffer
       if (buffer[0]==TEXMACS_DATA_COMMAND){
 	int bs=buffer.size();
@@ -1601,7 +1715,7 @@ int main(int ARGC, char *ARGV[]){
       if ( buffer=="quit") 
 	break; // end of session
       // Begin answer
-      putchar( TEXMACS_DATA_BEGIN); 
+      putchar(TEXMACS_DATA_BEGIN);
       printf("verbatim:");
       // ONLINE HELP
       if (buffer=="?"){
@@ -1701,16 +1815,24 @@ int main(int ARGC, char *ARGV[]){
     int taillemax=1000;
     if (getenv("GIAC_TAILLEMAX"))
       taillemax=atoi(getenv("GIAC_TAILLEMAX"));
-    struct tms start, end;  
+#ifndef HAVE_NO_SYS_TIMES_H
+    struct tms start, end;
+#else
+	clock_t start, end;
+#endif
     using_history();
-    cout << "Welcome to giac readline interface" << '\n';
-    cout << "(c) 2001,2020 B. Parisse & others" << '\n';
+    cout << "Welcome to giac readline interface, version " << GIAC_VERSION << '\n';
+    cout << "(c) 2001,2021 B. Parisse & others" << '\n';
     cout << "Homepage http://www-fourier.ujf-grenoble.fr/~parisse/giac.html" << '\n';
     cout << "Released under the GPL license 3.0 or above" << '\n';
     cout << "See http://www.gnu.org for license details" << '\n';
     cout << "May contain BSD licensed software parts (lapack, atlas, tinymt)" << '\n';
     cout << "-------------------------------------------------" << '\n';
+#ifdef __MINGW_H
+    cout << "Press CTRL and C or D simultaneously to finish session" << '\n';
+#else
     cout << "Press CTRL and D simultaneously to finish session" << '\n';
+#endif
     cout << "Type ?commandname for help" << '\n';
     for (int count=0;;++count) {
       char * res=rl_gets(count);
@@ -1725,10 +1847,15 @@ int main(int ARGC, char *ARGV[]){
       }
       if (s=="xcas"){
 	python_compat(python_compat(contextptr)&3,contextptr);
-	printf("%s\n","Giac 1.6.0");
+	printf("%s\n","Giac 1.7.0");
 	continue;
       }
-      if (micropy_evaled(s,contextptr))
+      if (s=="js"){
+	python_compat(-1,contextptr);
+	printf("%s\n","QuickJS");
+	continue;
+      }
+      if (micropyjs_evaled(s,contextptr))
 	continue;
       if (insage && bs && s[bs-1]==63){
 	string complete_string(s.substr(0,bs-1));
@@ -1775,12 +1902,20 @@ int main(int ARGC, char *ARGV[]){
 #ifdef __APPLE__
       unsigned startc=clock();
 #endif
+#ifndef HAVE_NO_SYS_TIMES_H
       times(&start);
+#else
+      start=clock();
+#endif
       xcas::icas_eval(gq,ge,reading_file,filename,contextptr);
 #ifdef __APPLE_
       startc=clock()-startc;
 #endif
+#ifndef HAVE_NO_SYS_TIMES_H
       times(&end);
+#else
+      end=clock();
+#endif
       giac::history_in(contextptr).push_back(gq);
       giac::history_out(contextptr).push_back(ge);
       // 2-d plot?
