@@ -1160,7 +1160,10 @@ namespace giac {
 
   const char * identificateur::print(GIAC_CONTEXT) const{
     if (!strcmp(id_name,string_pi)){
-#ifndef KHICAS
+#ifdef NUMWORKS
+      return string_pi;
+#endif
+#if !defined KHICAS 
       if (abs_calc_mode(contextptr)==38)
 #endif
 	return "π";
