@@ -57,10 +57,10 @@ namespace giac {
     b=tmp;
   }
 
-  index_t index_gcd(const index_t & a,const index_t & b){
+  void index_gcd(const index_t & a,const index_t & b,index_t & res){
     index_t::const_iterator ita=a.begin(),itaend=a.end(),itb=b.begin();
     unsigned s=unsigned(itaend-ita);
-    index_t res(s);
+    res.resize(s);
     index_t::iterator itres=res.begin();  
 #ifdef DEBUG_SUPPORT
     if (s!=b.size())
@@ -68,6 +68,11 @@ namespace giac {
 #endif // DEBUG_SUPPORT
     for (;ita!=itaend;++itb,++itres,++ita)
       *itres=giacmin(*ita,*itb);
+  }
+
+  index_t index_gcd(const index_t & a,const index_t & b){
+    index_t res;
+    index_gcd(a,b,res);
     return res;
   }
 
@@ -220,13 +225,13 @@ namespace giac {
 
   void add_print_INT_(string & s,int i){
     char c[256];
-    my_sprintf(c,"%d",i);
+    sprint_int(c,i);//my_sprintf(c,"%d",i);
     s += c;
   }
 
   string print_INT_(int i){
     char c[256];
-    my_sprintf(c,"%d",i);
+    sprint_int(c,i);//my_sprintf(c,"%d",i);
     return c;
   }
 
@@ -243,11 +248,22 @@ namespace giac {
   }
 
   string binary_print_INT_(int i){
+    if (i==0)
+      return "0b0";
     char c[256];
+#if 1
+    unsigned ii=i;
+    int j=sizeinbase2(ii);
+    c[j]=0;
+    for (--j;ii;--j,ii/=2){
+      c[j]='0'+(ii%2);
+    }
+#else
     mpz_t tmp;
     mpz_init_set_ui(tmp, i);
     mpz_get_str(c, 2, tmp);
     mpz_clear(tmp);
+#endif
     return string("0b")+c;
   }
 
