@@ -45,6 +45,7 @@
       {"FALSE",1,0,_INT_BOOLEAN,T_NUMBER},
       {"FAUX",1,0,_INT_BOOLEAN,T_NUMBER},
       {"FROM",0,0,0,T_FROM},
+      {"False",1,0,_INT_BOOLEAN,T_NUMBER},
       {"Func",0,0,0,TI_PRGM},
       {"GLOBAL",0,1,0,T_LOCAL},
       {"IFERR",0,0,0,T_IFERR},
@@ -64,30 +65,39 @@
       {"TRUE",1,1,_INT_BOOLEAN,T_NUMBER},
       {"TRY",0,0,0,T_TRY},
       {"Then",0,0,0,T_THEN},
+      {"True",1,1,_INT_BOOLEAN,T_NUMBER},
       {"Try",0,0,0,TI_TRY},
       {"UNTIL",0,0,0,T_UNTIL},
+      {"Unary"         ,1,_PREFIX_OPERATOR , _INT_MUPADOPERATOR ,T_NUMBER},
       {"VRAI",1,1,_INT_BOOLEAN,T_NUMBER},
+      {"acyclic", 0, _GT_ACYCLIC, _INT_MAPLECONVERSION, T_TYPE_ID},
       {"adaptive"         ,1,_ADAPTIVE , _INT_PLOT ,T_NUMBER},
       {"algebraic"              ,0, _SYMB, _INT_TYPE, T_TYPE_ID},
       {"args",1,0,0,T_ARGS},
       {"arrow_line"         ,1, _CAP_FLAT_LINE, _INT_COLOR ,T_NUMBER},
       {"axes"         ,1,_AXES , _INT_PLOT ,T_NUMBER},
       {"axesfont"         ,1,_AXESFONT , _INT_PLOT ,T_NUMBER},
+      {"bandwidth",0,    _KDE_BANDWIDTH, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"bareiss"         ,1, _BAREISS, _INT_SOLVER,T_NUMBER},
       {"base"         ,1,_BASE , _INT_MAPLECONVERSION ,T_NUMBER},
       {"begin",0,0,0,T_BLOC_BEGIN},
+      {"bins",0,    _KDE_BINS, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"bipartite",0,    _GT_BIPARTITE, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"bisection_solver"         ,1, _BISECTION_SOLVER, _INT_SOLVER,T_NUMBER},
       {"blanc"         ,1, _WHITE, _INT_COLOR ,T_NUMBER},
       {"bleu"         ,1, _BLUE, _INT_COLOR ,T_NUMBER},
+      {"blue"         ,1, _BLUE, _INT_COLOR ,T_NUMBER},
       {"brent_solver"         ,1, _BRENT_SOLVER, _INT_SOLVER,T_NUMBER},
+      {"brown"         ,1, 47624, _INT_COLOR ,T_NUMBER},
       {"by",1,0,0,T_BY},
       {"cap_flat_line"         ,1, _CAP_FLAT_LINE, _INT_COLOR ,T_NUMBER},
       {"cap_round_line"         ,1, _CAP_ROUND_LINE, _INT_COLOR ,T_NUMBER},
       {"cap_square_line"         ,1, _CAP_SQUARE_LINE, _INT_COLOR ,T_NUMBER},
       {"case",0,0,0,T_CASE},
       {"catch",0,0,0,T_CATCH},
-      {"complex"               ,0, _CPLX, _INT_TYPE, T_TYPE_ID},
+      // {"complex"               ,0, _CPLX, _INT_TYPE, T_TYPE_ID},
       {"confrac"         ,1,_CONFRAC , _INT_MAPLECONVERSION ,T_NUMBER},
+      {"connected",0,    _GT_CONNECTED, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"continue",0,0,0,T_CONTINUE},
       {"coords"         ,1, _COORDS, _INT_PLOT ,T_NUMBER},
       {"cross_point"         ,1, 0  , _INT_COLOR ,T_NUMBER},
@@ -95,7 +105,9 @@
       {"dash_line"         ,1, _DASH_LINE, _INT_COLOR ,T_NUMBER},
       {"dashdot_line"         ,1, _DASHDOT_LINE, _INT_COLOR ,T_NUMBER},
       {"dashdotdot_line"         ,1, _DASHDOTDOT_LINE, _INT_COLOR ,T_NUMBER},
+      {"de",0,0,0,T_FROM},
       {"default",1,0,0,T_DEFAULT},
+      {"directed",0,    _GT_DIRECTED, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"dnewton_solver"         ,1, _DNEWTON_SOLVER, _INT_SOLVER,T_NUMBER},
       {"dot_line"         ,1, _DOT_LINE, _INT_COLOR ,T_NUMBER},
       {"double"               ,0, _DOUBLE_, _INT_TYPE, T_TYPE_ID},
@@ -108,7 +120,7 @@
       {"end_for",0,2,0,T_BLOC_END},
       {"end_if",0,4,0,T_BLOC_END},
       {"end_proc",0,3,0,T_BLOC_END},
-      {"end_while",0,2,0,T_BLOC_END},
+      {"end_while",0,8,0,T_BLOC_END},
       {"endfunc",0,3,0,T_BLOC_END},
       {"epaisseur"         ,1, _THICKNESS, _INT_PLOT ,T_NUMBER},
       {"epaisseur_ligne_1"         ,1, 0 , _INT_COLOR ,T_NUMBER},
@@ -137,10 +149,12 @@
       {"faux",1,0,_INT_BOOLEAN,T_NUMBER},
       {"ffaire",0,2,0,T_BLOC_END},
       {"ffonction",0,3,0,T_BLOC_END},
+      {"ffunction",0,3,0,T_BLOC_END},
       {"fi",0,4,0,T_BLOC_END},
       {"filled"         ,1, _FILL_POLYGON, _INT_COLOR ,T_NUMBER},
       {"float"                ,0, _DOUBLE_, _INT_TYPE, T_TYPE_ID},
       {"font"         ,1,_FONT , _INT_PLOT ,T_NUMBER},
+      {"for",0,2,0,T_FOR},
       {"fpour",0,2,0,T_BLOC_END},
       {"frames"         ,1,_FRAMES , _INT_PLOT ,T_NUMBER},
       {"from",0,0,0,T_FROM},
@@ -219,12 +233,15 @@
       {"golub_reinsch_decomp"         ,1, _GOLUB_REINSCH_DECOMP, _INT_SOLVER,T_NUMBER},
       {"golub_reinsch_mod_decomp"         ,1, _GOLUB_REINSCH_MOD_DECOMP, _INT_SOLVER,T_NUMBER},
       {"gomme"         ,1, _WHITE, /* was 49 */ _INT_COLOR ,T_NUMBER},
+      {"green"         ,1, _GREEN, _INT_COLOR ,T_NUMBER},
+      {"grey"         ,1, 44373, _INT_COLOR ,T_NUMBER},
       {"groebner",1,_GROEBNER,_INT_MAPLELIB,T_MAPLELIB},
       {"hybrid_solver"         ,1, _HYBRID_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybridj_solver"         ,1, _HYBRIDJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybrids_solver"         ,1, _HYBRIDS_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybridsj_solver"         ,1, _HYBRIDSJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"identifier"            ,0, _IDNT, _INT_TYPE, T_TYPE_ID},
+      {"if",0,2,0,T_IF},
       {"in",0,0,0,T_IN},
       {"integer"               ,0, _ZINT, _INT_TYPE, T_TYPE_ID},
       {"intersect",0,0,0,T_INTERSECT},
@@ -233,11 +250,13 @@
       {"jaune"         ,1, _YELLOW, _INT_COLOR ,T_NUMBER},
       {"jusqu_a",0,0,0,T_UNTIL},
       {"jusqua",0,0,0,T_UNTIL},
+      {"jusque",0,1,0,T_TO},
       {"keep_pivot"         ,1, _KEEP_PIVOT, _INT_SOLVER,T_NUMBER},
       {"labeldirections"         ,1, _LABELDIRECTIONS, _INT_PLOT ,T_NUMBER},
       {"labelfont"         ,1, _LABELFONT, _INT_PLOT ,T_NUMBER},
       {"labels"         ,1, _LABELS, _INT_PLOT ,T_NUMBER},
       {"left_rectangle"         ,1, _RECTANGLE_GAUCHE, _INT_SOLVER,T_NUMBER},
+      {"let",0,0,0,T_LOCAL},
       {"ligne_chapeau_carre"         ,1, _CAP_SQUARE_LINE, _INT_COLOR ,T_NUMBER},
       {"ligne_chapeau_plat"         ,1, _CAP_FLAT_LINE, _INT_COLOR ,T_NUMBER},
       {"ligne_chapeau_rond"         ,1, _CAP_ROUND_LINE, _INT_COLOR ,T_NUMBER},
@@ -258,6 +277,36 @@
       {"linestyle"         ,1, _LINESTYLE, _INT_PLOT ,T_NUMBER},
       {"local",0,0,0,T_LOCAL},
       {"localbloc",0,0,0,T_LOCALBLOC},
+      {"lp_assume"               ,0, _LP_ASSUME, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_bestlocalbound",0,    _LP_BEST_LOCAL_BOUND, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_bestprojection",0,    _LP_BEST_PROJECTION, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_binary"               ,0, _LP_BINARY, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_binaryvariables"               ,0, _LP_BINARYVARIABLES, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_breadthfirst",0,    _LP_BREADTHFIRST, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_depthfirst",0,    _LP_DEPTHFIRST, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_depthlimit"               ,0, _LP_DEPTHLIMIT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_firstfractional",0,    _LP_FIRSTFRACTIONAL, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_gaptolerance",0,    _LP_GAP_TOLERANCE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_heuristic",0,    _LP_HEURISTIC, _INT_MAPLECONVERSION,T_TYPE_ID},      {"lp_hybrid",0,    _LP_HYBRID, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_integer"               ,0, _LP_INTEGER, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_integervariables"               ,0, _LP_INTEGERVARIABLES, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_interiorpoint"               ,0, _LP_INTERIOR_POINT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_iterationlimit",0,    _LP_ITERATION_LIMIT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_lastfractional",0,    _LP_LASTFRACTIONAL, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_maxcuts",0,    _LP_MAX_CUTS, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_maximize"               ,0, _LP_MAXIMIZE, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_method"               ,0, _LP_METHOD, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_mostfractional",0,    _LP_MOSTFRACTIONAL, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_nodelimit"               ,0, _LP_NODE_LIMIT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_nodeselect",0,    _LP_NODESELECT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_nonnegative"               ,0, _LP_NONNEGATIVE, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_nonnegint"               ,0, _LP_NONNEGINT, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_presolve",0,    _LP_PRESOLVE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_pseudocost",0,    _LP_PSEUDOCOST, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_simplex"               ,0, _LP_SIMPLEX, _INT_MAPLECONVERSION, T_TYPE_ID},
+      {"lp_timelimit",0,    _LP_TIME_LIMIT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_varselect",0,    _LP_VARSELECT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"lp_verbose",0,    _LP_VERBOSE, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"magenta"         ,1, _MAGENTA, _INT_COLOR ,T_NUMBER},
       {"middle_point"         ,1, _POINT_MILIEU, _INT_SOLVER,T_NUMBER},
       {"minor_det"         ,1, _MINOR_DET, _INT_SOLVER,T_NUMBER},
@@ -267,6 +316,20 @@
       {"newton_solver"         ,1, _NEWTON_SOLVER, _INT_SOLVER,T_NUMBER},
       {"newtonj_solver"         ,1, _NEWTONJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"next",0,0,0,T_CONTINUE},
+      {"nlp_binary",0,    _NLP_BINARY, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_binaryvariables",0,    _NLP_BINARYVARIABLES, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_feasibilitytolerance",0,    _NLP_FEAS_TOL, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_initialpoint",0,    _NLP_INITIALPOINT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_integer",0,    _NLP_INTEGER, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_integertolerance",0,    _NLP_INT_TOL, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_integervariables",0,    _NLP_INTEGERVARIABLES, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_iterationlimit",0,    _NLP_ITERATIONLIMIT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_maximize",0,    _NLP_MAXIMIZE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_nonnegative",0,    _NLP_NONNEGATIVE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_nonnegint",0,    _NLP_NONNEGINT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_precision",0,    _NLP_PRECISION, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_presolve",0,    _NLP_PRESOLVE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_samples",0,    _NLP_SAMPLES, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"noir"         ,1, _BLACK, _INT_COLOR ,T_NUMBER},
       {"nonnegint"               ,0, _NONNEGINT, _INT_MAPLECONVERSION, T_TYPE_ID},
       {"nonposint"               ,0, _NONPOSINT, _INT_MAPLECONVERSION, T_TYPE_ID},
@@ -275,8 +338,11 @@
       {"numtheory",1,_NUMTHEORY,_INT_MAPLELIB,T_MAPLELIB},
       {"od",0,9,0,T_BLOC_END},
       {"of",0,0,0,T_OF},
+      {"orange"         ,1, 64800, _INT_COLOR ,T_NUMBER},
       {"otherwise",0,0,0,T_DEFAULT},
       {"parfrac"         ,1,_PARFRAC , _INT_MAPLECONVERSION ,T_NUMBER},
+      {"pink"         ,1, 65017, _INT_COLOR ,T_NUMBER},
+      {"planar",0,    _GT_PLANAR, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"plex"         ,1,_PLEX_ORDER , _INT_GROEBNER ,T_NUMBER},
       {"plus_point"         ,1, _POINT_PLUS , _INT_COLOR ,T_NUMBER},
       {"point_carre"         ,1, _POINT_CARRE  , _INT_COLOR ,T_NUMBER},
@@ -300,6 +366,7 @@
       {"posint"               ,0, _POSINT, _INT_MAPLECONVERSION, T_TYPE_ID},
       {"proc",0,0,0,T_PROC},
       {"program",0,0,0,T_PROGRAM},
+      {"purple"         ,1, 43029, _INT_COLOR ,T_NUMBER},
       {"quadrant1"         ,1, _QUADRANT1 , _INT_COLOR ,T_NUMBER},
       {"quadrant2"         ,1, _QUADRANT2 , _INT_COLOR ,T_NUMBER},
       {"quadrant3"         ,1, _QUADRANT3 , _INT_COLOR ,T_NUMBER},
@@ -308,8 +375,10 @@
       {"rational_det"         ,1, _RATIONAL_DET, _INT_SOLVER,T_NUMBER},
       {"rectangle_droit"         ,1, _RECTANGLE_DROIT, _INT_SOLVER,T_NUMBER},
       {"rectangle_gauche"         ,1, _RECTANGLE_GAUCHE, _INT_SOLVER,T_NUMBER},
+      {"red"         ,1, _RED, _INT_COLOR ,T_NUMBER},
       {"rempli"         ,1, _FILL_POLYGON , _INT_COLOR ,T_NUMBER},
       {"resolution"         ,1,_RESOLUTION , _INT_PLOT ,T_NUMBER},
+      {"return",0,2,0,T_RETURN},
       {"revlex"         ,1,_REVLEX_ORDER , _INT_GROEBNER ,T_NUMBER},
       {"rhombus_point"         ,1, _POINT_LOSANGE , _INT_COLOR ,T_NUMBER},
       {"right_rectangle"         ,1, _RECTANGLE_DROIT, _INT_SOLVER,T_NUMBER},
@@ -324,6 +393,7 @@
       {"set"         ,0,_SET__VECT , _INT_MAPLECONVERSION ,T_TYPE_ID},
       {"simpson"         ,1, _SIMPSON, _INT_SOLVER,T_NUMBER},
       {"solid_line"         ,1, 0, _INT_COLOR ,T_NUMBER},
+      {"spring",0,    _GT_SPRING, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"square_point"         ,1, _POINT_CARRE  , _INT_COLOR ,T_NUMBER},
       {"stack",0,0,0,T_STACK},
       {"star_point"         ,1, _POINT_ETOILE , _INT_COLOR ,T_NUMBER},
@@ -344,6 +414,7 @@
       {"trames"         ,1,_FRAMES , _INT_PLOT ,T_NUMBER},
       {"trapeze"         ,1, _TRAPEZE, _INT_SOLVER,T_NUMBER},
       {"trapezoid"         ,1, _TRAPEZE, _INT_SOLVER,T_NUMBER},
+      {"tree",0,    _GT_TREE, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"triangle_point"         ,1, _POINT_TRIANGLE , _INT_COLOR ,T_NUMBER},
       {"trig"         ,1,_TRIG , _INT_MAPLECONVERSION ,T_NUMBER},
       {"true",1,1,_INT_BOOLEAN,T_NUMBER},
@@ -359,10 +430,14 @@
       {"view"         ,1, _VIEW, _INT_PLOT ,T_NUMBER},
       {"vrai",1,1,_INT_BOOLEAN,T_NUMBER},
       {"vstep"         ,1, _VSTEP , _INT_PLOT ,T_NUMBER},
+      {"weighted",0,    _GT_WEIGHTED, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"weights",0,    _GT_WEIGHTS, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"while",0,2,0,T_WHILE},
       {"with_cocoa"         ,1,_WITH_COCOA , _INT_GROEBNER ,T_NUMBER},
       {"with_f5"         ,1,_WITH_F5 , _INT_GROEBNER ,T_NUMBER},
       {"xstep"         ,1, _XSTEP , _INT_PLOT ,T_NUMBER},
       {"xtickmarks"         ,1,_XTICKMARKS , _INT_PLOT ,T_NUMBER},
+      {"yellow"         ,1, _YELLOW, _INT_COLOR ,T_NUMBER},
       {"ystep"         ,1, _YSTEP , _INT_PLOT ,T_NUMBER},
       {"zstep"         ,1, _ZSTEP , _INT_PLOT ,T_NUMBER},
       {"αστροειδές_σημείο"         ,1, _POINT_ETOILE , _INT_COLOR ,T_NUMBER},
