@@ -23,6 +23,14 @@
 namespace giac {
 #endif // ndef NO_NAMESPACE_GIAC
   class gen;
+  struct cpureal_t {
+    double cpu;
+    double real;
+  };
+  inline std::ostream & operator << (std::ostream & os,const cpureal_t & cr){ return os << "[" << cr.cpu << "," << cr.real << "]"; }
+  inline cpureal_t operator -(const cpureal_t & t1,const cpureal_t & t2){ cpureal_t ans={std::floor(1e6*(t1.cpu-t2.cpu)+.5)*1e-6,std::floor(1e6*(t1.real-t2.real)+.5)*1e-6}; return ans;}
+  double realtime(); // since 2021
+  cpureal_t clock_realtime();
 
   gen _about(const gen & g,GIAC_CONTEXT);
   gen _zip(const gen & args,GIAC_CONTEXT);
