@@ -71,6 +71,7 @@ namespace giac {
   gen _semi_augment(const gen & g,GIAC_CONTEXT);
   gen _cumSum(const gen & g,GIAC_CONTEXT);
   gen _exp2list(const gen & g,GIAC_CONTEXT);
+  gen _list2exp(const gen & g,GIAC_CONTEXT);
   gen _list2mat(const gen & g,GIAC_CONTEXT);
   gen _deltalist(const gen & g,GIAC_CONTEXT);
   gen _mat2list(const gen & g,GIAC_CONTEXT);
@@ -153,9 +154,11 @@ namespace giac {
 #ifndef RTOS_THREADX
 #ifndef BESTA_OS
   extern unary_function_eval __getKey;
+  extern unary_function_eval __get_key;
 #endif
 #endif
   extern const unary_function_ptr * const  at_getKey;
+  extern const unary_function_ptr * const  at_keydown;
   extern const unary_function_ptr * const  at_numer;
   extern const unary_function_ptr * const  at_ClrIO;
   extern const unary_function_ptr * const  at_Output;
